==> zio-aws-iotanalytics_2.12-5.17.128.1-sources.jar: zio/aws/iotanalytics/model/DeleteDatasetContentRequest.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotanalytics.model.primitives.{
  DatasetContentVersion,
  DatasetName
}
import scala.jdk.CollectionConverters._
final case class DeleteDatasetContentRequest(
    datasetName: DatasetName,
    versionId: Option[DatasetContentVersion] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest = {
    import DeleteDatasetContentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
      .builder()
      .datasetName(DatasetName.unwrap(datasetName): java.lang.String)
      .optionallyWith(
        versionId.map(value =>
          DatasetContentVersion.unwrap(value): java.lang.String
        )
      )(_.versionId)
      .build()
  }
  def asReadOnly
      : zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly =
    zio.aws.iotanalytics.model.DeleteDatasetContentRequest.wrap(buildAwsValue())
}
object DeleteDatasetContentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.DeleteDatasetContentRequest =
      zio.aws.iotanalytics.model
        .DeleteDatasetContentRequest(datasetName, versionId.map(value => value))
    def datasetName: DatasetName
    def versionId: Option[DatasetContentVersion]
    def getDatasetName: ZIO[Any, Nothing, DatasetName] =
      ZIO.succeed(datasetName)
    def getVersionId: ZIO[Any, AwsError, DatasetContentVersion] =
      AwsError.unwrapOptionField("versionId", versionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ) extends zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly {
    override val datasetName: DatasetName =
      zio.aws.iotanalytics.model.primitives.DatasetName(impl.datasetName())
    override val versionId: Option[DatasetContentVersion] = scala
      .Option(impl.versionId())
      .map(value =>
        zio.aws.iotanalytics.model.primitives.DatasetContentVersion(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ): zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotanalytics_2.13-7.21.15.10-sources.jar: zio/aws/iotanalytics/model/DeleteDatasetContentRequest.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.iotanalytics.model.primitives.{
  DatasetContentVersion,
  DatasetName
}
import scala.jdk.CollectionConverters._
final case class DeleteDatasetContentRequest(
    datasetName: DatasetName,
    versionId: Optional[DatasetContentVersion] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest = {
    import DeleteDatasetContentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
      .builder()
      .datasetName(DatasetName.unwrap(datasetName): java.lang.String)
      .optionallyWith(
        versionId.map(value =>
          DatasetContentVersion.unwrap(value): java.lang.String
        )
      )(_.versionId)
      .build()
  }
  def asReadOnly
      : zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly =
    zio.aws.iotanalytics.model.DeleteDatasetContentRequest.wrap(buildAwsValue())
}
object DeleteDatasetContentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.DeleteDatasetContentRequest =
      zio.aws.iotanalytics.model
        .DeleteDatasetContentRequest(datasetName, versionId.map(value => value))
    def datasetName: DatasetName
    def versionId: Optional[DatasetContentVersion]
    def getDatasetName: ZIO[Any, Nothing, DatasetName] =
      ZIO.succeed(datasetName)
    def getVersionId: ZIO[Any, AwsError, DatasetContentVersion] =
      AwsError.unwrapOptionField("versionId", versionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ) extends zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly {
    override val datasetName: DatasetName =
      zio.aws.iotanalytics.model.primitives.DatasetName(impl.datasetName())
    override val versionId: Optional[DatasetContentVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.versionId())
        .map(value =>
          zio.aws.iotanalytics.model.primitives.DatasetContentVersion(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.DeleteDatasetContentRequest
  ): zio.aws.iotanalytics.model.DeleteDatasetContentRequest.ReadOnly =
    new Wrapper(impl)
}
